library(bayestraitr)
library(ape)
library(paleotree )
library(phylobase)
library(phytools)
library(geosphere)
load('GTree_phylo4g_withClimateSimData.RDat')
d = bt_read.log("Anc_ASJP_continuous_est.Log.Log")

tree.chosen = tree4d
tips.to.remove  = tree4d@label[is.na(tree4d@data[1:length(tree4d@label),]$ASJPVowelRatio)]
tree.chosen = prune(tree.chosen,tips.exclude = tips.to.remove, trim.internal=T)

anc = apply(d[,grepl("^Est",names(d))],2,mean)
ancsd = apply(d[,grepl("^Est",names(d))],2,sd)


newdf = as.data.frame(tree.chosen@data)
newdf$node = 1:nrow(newdf)
newdf = newdf[,c('node', 'Longitude', 'Latitude', 'specH.mean', "Node.Age", 'ASJPVowelRatio', 'specH.mean.sim.gam')]
newdf$ASJPVowelRatio.sd = 0

newdf$ASJPVowelRatio[384:765] = anc
newdf$ASJPVowelRatio.sd[384:765] = ancsd

ancinfo = tree.chosen@edge

newdf$ancASJPVowelRatio = NA
newdf$ancASJPVowelRatio.sd = NA
newdf$mH = NA
newdf$ancAge = NA
newdf$ancnode = NA

for (i in 1:max(newdf$node)) {
  anc = ancinfo[ancinfo[,2] == i,1][[1]]
  newdf$ancnode[i] = anc
  if(anc > 0){
    newdf$ancASJPVowelRatio[newdf$node == i] = newdf$ASJPVowelRatio[newdf$node == anc]
    newdf$ancASJPVowelRatio.sd[newdf$node == i] = newdf$ASJPVowelRatio.sd[newdf$node == anc]
    newdf$mH[newdf$node == i] = mean(newdf$specH.mean.sim.gam[newdf$node == anc], newdf$specH.mean.sim.gam[newdf$node == i])
    newdf$ancAge[newdf$node == i] = newdf$Node.Age[newdf$node == anc]

    
  }

}

newdf$deltaAge = newdf$ancAge-newdf$Node.Age

for(i in 1:nrow(newdf)){
  tmp = tree.chosen@edge.length[paste(c(newdf$ancnode[i], newdf$node[i]), collapse = '-' )]
  newdf$deltaAge[i] = (333.54911/0.0033354911)*tmp[[1]]
}


get_extants <- function(age){

  agesdf$node[which(agesdf$age_upper >= age+0.01 & agesdf$age_lower <= age+0.01)]
  
}
ancinfo = tree.chosen@edge
ancinfo_age = ancinfo
agesdf = data.frame()
for (i in newdf$node){
  tmpdf = ancinfo_age[which(ancinfo_age[,2] == i),]
  if (tmpdf[1] == 0){
    agesdf = rbind(agesdf, data.frame('node' = i, 'age_upper' = Inf, 'age_lower' = newdf$Node.Age[which(newdf$node %in% tmpdf[2])]))
  }else{
    agesdf = rbind(agesdf, data.frame('node' = i, 'age_upper' = newdf$Node.Age[which(newdf$node == tmpdf[1])], 'age_lower' = newdf$Node.Age[which(newdf$node %in% tmpdf[2])]))
  }
}


geodist = distm(newdf[,c('Longitude','Latitude')], fun = distHaversine)/1000000
geodist = exp(-8 * geodist^2 )

weighted_means =c()

for(i in 1:nrow(newdf)){
  print(i/nrow(newdf))
  
  ASJPVowelRatiodf = newdf[which(newdf$node %in% get_extants(newdf$Node.Age[i])), c('ASJPVowelRatio', 'node', 'ancASJPVowelRatio') ]
  ASJPVowelRatiodf$weights = NA
  for(e in 1:nrow(ASJPVowelRatiodf)){
    ASJPVowelRatiodf$weights[e] = geodist[i, ASJPVowelRatiodf$node[e]]
  }
  
  ASJPVowelRatiodf$dASJPVowelRatio = ASJPVowelRatiodf$ASJPVowelRatio-ASJPVowelRatiodf$ancASJPVowelRatio
  ASJPVowelRatiodf = ASJPVowelRatiodf[ASJPVowelRatiodf$node != newdf$node[i],]
  weighted_means = c(weighted_means, weighted.mean(ASJPVowelRatiodf$dASJPVowelRatio, ASJPVowelRatiodf$weights))
  
}


newdf$neighbourmean = weighted_means


library(ecoPD)
phydist = ecoPD::pairdist(tree.chosen)*10
phydist = exp(-10 * phydist )

weighted_phymeans =c()

for(i in 1:nrow(newdf)){
  print(i/nrow(newdf))
  
  ASJPVowelRatiodf = newdf[which(newdf$node %in% get_extants(newdf$Node.Age[i])), c('ASJPVowelRatio', 'node', 'ancASJPVowelRatio') ]
  ASJPVowelRatiodf$weights = NA
  for(e in 1:nrow(ASJPVowelRatiodf)){
    ASJPVowelRatiodf$weights[e] = phydist[i, ASJPVowelRatiodf$node[e]]
  }

  ASJPVowelRatiodf = ASJPVowelRatiodf[ASJPVowelRatiodf$node != newdf$node[i],]
  weighted_phymeans = c(weighted_phymeans, weighted.mean(ASJPVowelRatiodf$ASJPVowelRatio, ASJPVowelRatiodf$weights))
  
}

newdf$phymean = weighted_phymeans


weighted_means_int =c()

for(i in 1:nrow(newdf)){
  print(i/nrow(newdf))

  ASJPVowelRatiodf = newdf[which(newdf$node %in% get_extants(newdf$Node.Age[i])), c('ASJPVowelRatio', 'node', 'ancASJPVowelRatio', 'Node.Age', 'ancAge') ]
  ASJPVowelRatiodf$weights = NA
  for(e in 1:nrow(ASJPVowelRatiodf)){
    ASJPVowelRatiodf$weights[e] = geodist[i, ASJPVowelRatiodf$node[e]]
  }
  ASJPVowelRatiodf$cutprop = NA
  for(e in 1:nrow(ASJPVowelRatiodf)){
    ASJPVowelRatiodf$cutprop[e] = 1-(newdf$Node.Age[i]-ASJPVowelRatiodf$Node.Age[e])/(ASJPVowelRatiodf$ancAge[e]-ASJPVowelRatiodf$Node.Age[e])
  }
  ASJPVowelRatiodf = ASJPVowelRatiodf[ASJPVowelRatiodf$node != newdf$node[i],]
  ASJPVowelRatiodf$ASJPVowelRatio = ASJPVowelRatiodf$ancASJPVowelRatio + (ASJPVowelRatiodf$ASJPVowelRatio-ASJPVowelRatiodf$ancASJPVowelRatio)*ASJPVowelRatiodf$cutprop
  weighted_means_int = c(weighted_means_int, weighted.mean(ASJPVowelRatiodf$ASJPVowelRatio, ASJPVowelRatiodf$weights))
  
}


newdf$neighbourmean_int = weighted_means_int


weighted_phymeans_int =c()

for(i in 1:nrow(newdf)){
  print(i/nrow(newdf))
  
  ASJPVowelRatiodf = newdf[which(newdf$node %in% get_extants(newdf$Node.Age[i])), c('ASJPVowelRatio', 'node', 'ancASJPVowelRatio', 'Node.Age', 'ancAge') ]
  ASJPVowelRatiodf$weights = NA
  for(e in 1:nrow(ASJPVowelRatiodf)){
    ASJPVowelRatiodf$weights[e] = phydist[i, ASJPVowelRatiodf$node[e]]
  }
  ASJPVowelRatiodf$cutprop = NA
  for(e in 1:nrow(ASJPVowelRatiodf)){
    ASJPVowelRatiodf$cutprop[e] = 1-(newdf$Node.Age[i]-ASJPVowelRatiodf$Node.Age[e])/(ASJPVowelRatiodf$ancAge[e]-ASJPVowelRatiodf$Node.Age[e])
  }
  ASJPVowelRatiodf = ASJPVowelRatiodf[ASJPVowelRatiodf$node != newdf$node[i],]
  ASJPVowelRatiodf$dASJPVowelRatio = (ASJPVowelRatiodf$ASJPVowelRatio-ASJPVowelRatiodf$ancASJPVowelRatio)*ASJPVowelRatiodf$cutprop
  weighted_phymeans_int = c(weighted_phymeans_int, weighted.mean(ASJPVowelRatiodf$dASJPVowelRatio, ASJPVowelRatiodf$weights))
  
}

newdf$phymean_int = weighted_phymeans_int



weighted_phyrate_abs =c()
weighted_phyrate =c()

for(i in 1:nrow(newdf)){
  print(i/nrow(newdf))
  
  ASJPVowelRatiodf = newdf
  ASJPVowelRatiodf$deltaAge = ASJPVowelRatiodf$deltaAge/1000
  ASJPVowelRatiodf$dASJPVowelRatio = ASJPVowelRatiodf$ASJPVowelRatio-ASJPVowelRatiodf$ancASJPVowelRatio
  ASJPVowelRatiodf$rate = ASJPVowelRatiodf$dASJPVowelRatio/ASJPVowelRatiodf$deltaAge
  ASJPVowelRatiodf$rate_abs = abs(ASJPVowelRatiodf$rate)
  ASJPVowelRatiodf$weights = NA
  for(e in 1:nrow(ASJPVowelRatiodf)){
    ASJPVowelRatiodf$weights[e] = phydist[i, ASJPVowelRatiodf$node[e]]
  }
  
  ASJPVowelRatiodf = ASJPVowelRatiodf[ASJPVowelRatiodf$node != newdf$node[i],]
  ASJPVowelRatiodf = ASJPVowelRatiodf[!is.na(ASJPVowelRatiodf$mH),]
  weighted_phyrate_abs = c(weighted_phyrate_abs, weighted.mean(ASJPVowelRatiodf$rate_abs, ASJPVowelRatiodf$weights))
  weighted_phyrate = c(weighted_phyrate, weighted.mean(ASJPVowelRatiodf$rate, ASJPVowelRatiodf$weights))
  
}

newdf$phyrate_abs = weighted_phyrate_abs
newdf$phyrate = weighted_phyrate




geodist = distm(newdf[,c('Longitude','Latitude')], fun = distHaversine)/1000000
disc_means_int =c()
disc_meds_int =c()
disc_means_int_sd=c()
for(i in 1:nrow(newdf)){
  print(i/nrow(newdf))
  
  ASJPVowelRatiodf = newdf[which(newdf$node %in% get_extants(newdf$Node.Age[i])), c('ASJPVowelRatio', 'node', 'ancASJPVowelRatio', 'Node.Age', 'ancAge') ]
  tmpgeo = geodist[i,]
  ASJPVowelRatiodf = ASJPVowelRatiodf[which(ASJPVowelRatiodf$node %in% which(tmpgeo < 0.5)),]
  ASJPVowelRatiodf$cutprop = NA
  for(e in 1:nrow(ASJPVowelRatiodf)){
    ASJPVowelRatiodf$cutprop[e] = 1-(newdf$Node.Age[i]-ASJPVowelRatiodf$Node.Age[e])/(ASJPVowelRatiodf$ancAge[e]-ASJPVowelRatiodf$Node.Age[e])
  }
  ASJPVowelRatiodf = ASJPVowelRatiodf[ASJPVowelRatiodf$node != newdf$node[i],]
  ASJPVowelRatiodf$ASJPVowelRatio = ASJPVowelRatiodf$ancASJPVowelRatio + (ASJPVowelRatiodf$ASJPVowelRatio-ASJPVowelRatiodf$ancASJPVowelRatio)*ASJPVowelRatiodf$cutprop
  disc_means_int = c(disc_means_int, mean(ASJPVowelRatiodf$ASJPVowelRatio))
  disc_meds_int = c(disc_meds_int, median(ASJPVowelRatiodf$ASJPVowelRatio))
  disc_means_int_sd = c(disc_means_int_sd, sd(ASJPVowelRatiodf$ASJPVowelRatio))
  
}

newdf$disc_neighbourmeans_int_sd = disc_means_int_sd
newdf$disc_neighbourmeans_int = disc_means_int
newdf$disc_neighbourmed_int = disc_meds_int


phydist = ecoPD::pairdist(tree.chosen)
disc_phymeans_int =c()
disc_phymed_int =c()
disc_phymeans_int_sd =c()
for(i in 1:nrow(newdf)){
  print(i/nrow(newdf))
  
  ASJPVowelRatiodf = newdf
  tmpphylo = phydist[i,]
  ASJPVowelRatiodf = ASJPVowelRatiodf[which(ASJPVowelRatiodf$node %in% which(tmpphylo < 0.02)),]
  ASJPVowelRatiodf = ASJPVowelRatiodf[ASJPVowelRatiodf$node != newdf$node[i],]
  ASJPVowelRatiodf = ASJPVowelRatiodf[ASJPVowelRatiodf$node != newdf$ancnode[i],]
  if(nrow(ASJPVowelRatiodf) == 0){
    disc_phymed_int = c(disc_phymed_int, 0)
    disc_phymeans_int = c(disc_phymeans_int, 0)
    disc_phymeans_int_sd= c(disc_phymeans_int_sd, 0)
  }else if(nrow(ASJPVowelRatiodf) == 1){
    disc_phymed_int = c(disc_phymed_int, median(ASJPVowelRatiodf$ASJPVowelRatio))
    disc_phymeans_int = c(disc_phymeans_int, mean(ASJPVowelRatiodf$ASJPVowelRatio))
    disc_phymeans_int_sd= c(disc_phymeans_int_sd, 0)
  }else{
    disc_phymeans_int = c(disc_phymeans_int, mean(ASJPVowelRatiodf$ASJPVowelRatio))
    disc_phymed_int = c(disc_phymed_int, median(ASJPVowelRatiodf$ASJPVowelRatio))
    disc_phymeans_int_sd= c(disc_phymeans_int_sd, sd(ASJPVowelRatiodf$ASJPVowelRatio))
  }
  
}
newdf$disc_phymed_int = disc_phymed_int
newdf$disc_phymeans_int = disc_phymeans_int
newdf$disc_phymeans_int_sd = disc_phymeans_int_sd


write.csv(newdf, file = 'purelin_df_ASJPVowelRatio.csv')

save(geodist,file = 'geodist_ASJPVowelRatio.rda')
save(phydist,file = 'phylodist_ASJPVowelRatio.rda')


