library(bayestraitr)
library(ape)
library(paleotree )
library(phylobase)
library(phytools)
library(geosphere)
load('GTree_phylo4g_withClimateSimData.RDat')
d = bt_read.log("Anc_VOWELRATIO_continuous_est.Log.Log")

tree4d@data$Vowelratio = tree4d@data$Vowels/(tree4d@data$Vowels+tree4d@data$Consonants)

tree.chosen = tree4d
tips.to.remove  = tree4d@label[is.na(tree4d@data[1:length(tree4d@label),]$Vowelratio)]
tree.chosen = prune(tree.chosen,tips.exclude = tips.to.remove, trim.internal=T)

anc = apply(d[,grepl("^Est",names(d))],2,mean)
ancsd = apply(d[,grepl("^Est",names(d))],2,sd)


newdf = as.data.frame(tree.chosen@data)
newdf$node = 1:nrow(newdf)
newdf = newdf[,c('node', 'Longitude', 'Latitude', 'specH.mean', "Node.Age", 'Vowelratio', 'specH.mean.sim.gam')]
newdf$Vowelratio.sd = 0

newdf$Vowelratio[162:321] = anc
newdf$Vowelratio.sd[162:321] = ancsd

ancinfo = tree.chosen@edge

newdf$ancVowelratio = NA
newdf$ancVowelratio.sd = NA
newdf$mH = NA
newdf$ancAge = NA
newdf$ancnode = NA

for (i in 1:max(newdf$node)) {
  anc = ancinfo[ancinfo[,2] == i,1][[1]]
  newdf$ancnode[i] = anc
  if(anc > 0){
    newdf$ancVowelratio[newdf$node == i] = newdf$Vowelratio[newdf$node == anc]
    newdf$ancVowelratio.sd[newdf$node == i] = newdf$Vowelratio.sd[newdf$node == anc]
    newdf$mH[newdf$node == i] = mean(newdf$specH.mean.sim.gam[newdf$node == anc], newdf$specH.mean.sim.gam[newdf$node == i])
    newdf$ancAge[newdf$node == i] = newdf$Node.Age[newdf$node == anc]

    
  }

}

newdf$deltaAge = newdf$ancAge-newdf$Node.Age

for(i in 1:nrow(newdf)){
  tmp = tree.chosen@edge.length[paste(c(newdf$ancnode[i], newdf$node[i]), collapse = '-' )]
  newdf$deltaAge[i] = (333.54911/0.0033354911)*tmp[[1]]
}


get_extants <- function(age){

  agesdf$node[which(agesdf$age_upper >= age+0.01 & agesdf$age_lower <= age+0.01)]
  
}
ancinfo = tree.chosen@edge
ancinfo_age = ancinfo
agesdf = data.frame()
for (i in newdf$node){
  tmpdf = ancinfo_age[which(ancinfo_age[,2] == i),]
  if (tmpdf[1] == 0){
    agesdf = rbind(agesdf, data.frame('node' = i, 'age_upper' = Inf, 'age_lower' = newdf$Node.Age[which(newdf$node %in% tmpdf[2])]))
  }else{
    agesdf = rbind(agesdf, data.frame('node' = i, 'age_upper' = newdf$Node.Age[which(newdf$node == tmpdf[1])], 'age_lower' = newdf$Node.Age[which(newdf$node %in% tmpdf[2])]))
  }
}


geodist = distm(newdf[,c('Longitude','Latitude')], fun = distHaversine)/1000000
geodist = exp(-8 * geodist^2 )

weighted_means =c()

for(i in 1:nrow(newdf)){
  print(i/nrow(newdf))
  
  Vowelratiodf = newdf[which(newdf$node %in% get_extants(newdf$Node.Age[i])), c('Vowelratio', 'node', 'ancVowelratio') ]
  Vowelratiodf$weights = NA
  for(e in 1:nrow(Vowelratiodf)){
    Vowelratiodf$weights[e] = geodist[i, Vowelratiodf$node[e]]
  }
  
  Vowelratiodf$dVowelratio = Vowelratiodf$Vowelratio-Vowelratiodf$ancVowelratio
  Vowelratiodf = Vowelratiodf[Vowelratiodf$node != newdf$node[i],]
  weighted_means = c(weighted_means, weighted.mean(Vowelratiodf$dVowelratio, Vowelratiodf$weights))
  
}


newdf$neighbourmean = weighted_means


library(ecoPD)
phydist = ecoPD::pairdist(tree.chosen)*10
phydist = exp(-10 * phydist )

weighted_phymeans =c()

for(i in 1:nrow(newdf)){
  print(i/nrow(newdf))
  
  Vowelratiodf = newdf[which(newdf$node %in% get_extants(newdf$Node.Age[i])), c('Vowelratio', 'node', 'ancVowelratio') ]
  Vowelratiodf$weights = NA
  for(e in 1:nrow(Vowelratiodf)){
    Vowelratiodf$weights[e] = phydist[i, Vowelratiodf$node[e]]
  }
  
  Vowelratiodf = Vowelratiodf[Vowelratiodf$node != newdf$node[i],]
  weighted_phymeans = c(weighted_phymeans, weighted.mean(Vowelratiodf$Vowelratio, Vowelratiodf$weights))
  
}

newdf$phymean = weighted_phymeans


weighted_means_int =c()

for(i in 1:nrow(newdf)){
  print(i/nrow(newdf))

  Vowelratiodf = newdf[which(newdf$node %in% get_extants(newdf$Node.Age[i])), c('Vowelratio', 'node', 'ancVowelratio', 'Node.Age', 'ancAge') ]
  Vowelratiodf$weights = NA
  for(e in 1:nrow(Vowelratiodf)){
    Vowelratiodf$weights[e] = geodist[i, Vowelratiodf$node[e]]
  }
  Vowelratiodf$cutprop = NA
  for(e in 1:nrow(Vowelratiodf)){
    Vowelratiodf$cutprop[e] = 1-(newdf$Node.Age[i]-Vowelratiodf$Node.Age[e])/(Vowelratiodf$ancAge[e]-Vowelratiodf$Node.Age[e])
  }
  Vowelratiodf = Vowelratiodf[Vowelratiodf$node != newdf$node[i],]
  Vowelratiodf$Vowelratio = Vowelratiodf$ancVowelratio + (Vowelratiodf$Vowelratio-Vowelratiodf$ancVowelratio)*Vowelratiodf$cutprop
  weighted_means_int = c(weighted_means_int, weighted.mean(Vowelratiodf$Vowelratio, Vowelratiodf$weights))
  
}


newdf$neighbourmean_int = weighted_means_int


weighted_phymeans_int =c()

for(i in 1:nrow(newdf)){
  print(i/nrow(newdf))
  
  Vowelratiodf = newdf[which(newdf$node %in% get_extants(newdf$Node.Age[i])), c('Vowelratio', 'node', 'ancVowelratio', 'Node.Age', 'ancAge') ]
  Vowelratiodf$weights = NA
  for(e in 1:nrow(Vowelratiodf)){
    Vowelratiodf$weights[e] = phydist[i, Vowelratiodf$node[e]]
  }
  Vowelratiodf$cutprop = NA
  for(e in 1:nrow(Vowelratiodf)){
    Vowelratiodf$cutprop[e] = 1-(newdf$Node.Age[i]-Vowelratiodf$Node.Age[e])/(Vowelratiodf$ancAge[e]-Vowelratiodf$Node.Age[e])
  }
  Vowelratiodf = Vowelratiodf[Vowelratiodf$node != newdf$node[i],]
  Vowelratiodf$dVowelratio = (Vowelratiodf$Vowelratio-Vowelratiodf$ancVowelratio)*Vowelratiodf$cutprop
  weighted_phymeans_int = c(weighted_phymeans_int, weighted.mean(Vowelratiodf$dVowelratio, Vowelratiodf$weights))
  
}

newdf$phymean_int = weighted_phymeans_int



weighted_phyrate_abs =c()
weighted_phyrate =c()
phyrate =c()
phyrate_sd =c()

for(i in 1:nrow(newdf)){
  print(i/nrow(newdf))
  
  Vowelratiodf = newdf
  Vowelratiodf$deltaAge = Vowelratiodf$deltaAge/1000
  Vowelratiodf$dVowelratio = Vowelratiodf$Vowelratio-Vowelratiodf$ancVowelratio
  Vowelratiodf$rate = Vowelratiodf$dVowelratio/Vowelratiodf$deltaAge
  Vowelratiodf$rate_abs = abs(Vowelratiodf$rate)
  Vowelratiodf$weights = NA
  for(e in 1:nrow(Vowelratiodf)){
    Vowelratiodf$weights[e] = phydist[i, Vowelratiodf$node[e]]
  }
  
  Vowelratiodf = Vowelratiodf[Vowelratiodf$node != newdf$node[i],]
  Vowelratiodf = Vowelratiodf[!is.na(Vowelratiodf$mH),]
  weighted_phyrate_abs = c(weighted_phyrate_abs, weighted.mean(Vowelratiodf$rate_abs, Vowelratiodf$weights))
  weighted_phyrate = c(weighted_phyrate, weighted.mean(Vowelratiodf$rate, Vowelratiodf$weights))
  
  
  
  Vowelratiodf = newdf
  tmpphylo = phydist[i,]
  Vowelratiodf = Vowelratiodf[which(Vowelratiodf$node %in% which(tmpphylo < 0.02)),]
  Vowelratiodf$deltaAge = Vowelratiodf$deltaAge/1000
  Vowelratiodf$dVowelratio = Vowelratiodf$Vowelratio-Vowelratiodf$ancVowelratio
  Vowelratiodf$rate = Vowelratiodf$dVowelratio/Vowelratiodf$deltaAge
  Vowelratiodf$rate_abs = abs(Vowelratiodf$rate)
  Vowelratiodf$weights = NA
  for(e in 1:nrow(Vowelratiodf)){
    Vowelratiodf$weights[e] = phydist[i, Vowelratiodf$node[e]]
  }
  
  Vowelratiodf = Vowelratiodf[Vowelratiodf$node != newdf$node[i],]
  Vowelratiodf = Vowelratiodf[!is.na(Vowelratiodf$mH),]
  phyrate = c(phyrate, mean(Vowelratiodf$rate))
  phyrate_sd = c(phyrate_sd, sd(Vowelratiodf$rate))
}

newdf$phyrate_abs = weighted_phyrate_abs
newdf$phyrate = phyrate
newdf$phyrate_sd = phyrate_sd



geodist = distm(newdf[,c('Longitude','Latitude')], fun = distHaversine)/1000000
disc_means_int =c()
disc_meds_int =c()
disc_means_int_sd=c()
for(i in 1:nrow(newdf)){
  print(i/nrow(newdf))
  
  Vowelratiodf = newdf[which(newdf$node %in% get_extants(newdf$Node.Age[i])), c('Vowelratio', 'node', 'ancVowelratio', 'Node.Age', 'ancAge') ]
  tmpgeo = geodist[i,]
  Vowelratiodf = Vowelratiodf[which(Vowelratiodf$node %in% which(tmpgeo < 0.5)),]
  Vowelratiodf$cutprop = NA
  for(e in 1:nrow(Vowelratiodf)){
    Vowelratiodf$cutprop[e] = 1-(newdf$Node.Age[i]-Vowelratiodf$Node.Age[e])/(Vowelratiodf$ancAge[e]-Vowelratiodf$Node.Age[e])
  }
  Vowelratiodf = Vowelratiodf[Vowelratiodf$node != newdf$node[i],]
  Vowelratiodf$Vowelratio = Vowelratiodf$ancVowelratio + (Vowelratiodf$Vowelratio-Vowelratiodf$ancVowelratio)*Vowelratiodf$cutprop
  disc_means_int = c(disc_means_int, mean(Vowelratiodf$Vowelratio))
  disc_meds_int = c(disc_meds_int, median(Vowelratiodf$Vowelratio))
  disc_means_int_sd = c(disc_means_int_sd, sd(Vowelratiodf$Vowelratio))
  
}

newdf$disc_neighbourmeans_int_sd = disc_means_int_sd
newdf$disc_neighbourmeans_int = disc_means_int
newdf$disc_neighbourmed_int = disc_meds_int


phydist = ecoPD::pairdist(tree.chosen)
disc_phymeans_int =c()
disc_phymed_int =c()
disc_phymeans_int_sd =c()
for(i in 1:nrow(newdf)){
  print(i/nrow(newdf))
  
  Vowelratiodf = newdf
  tmpphylo = phydist[i,]
  Vowelratiodf = Vowelratiodf[which(Vowelratiodf$node %in% which(tmpphylo < 0.02)),]
  Vowelratiodf = Vowelratiodf[Vowelratiodf$node != newdf$node[i],]
  Vowelratiodf = Vowelratiodf[Vowelratiodf$node != newdf$ancnode[i],]
  if(nrow(Vowelratiodf) == 0){
    disc_phymed_int = c(disc_phymed_int, 0)
    disc_phymeans_int = c(disc_phymeans_int, 0)
    disc_phymeans_int_sd= c(disc_phymeans_int_sd, 0)
  }else if(nrow(Vowelratiodf) == 1){
    disc_phymed_int = c(disc_phymed_int, median(Vowelratiodf$Vowelratio))
    disc_phymeans_int = c(disc_phymeans_int, mean(Vowelratiodf$Vowelratio))
    disc_phymeans_int_sd= c(disc_phymeans_int_sd, 0)
  }else{
    disc_phymeans_int = c(disc_phymeans_int, mean(Vowelratiodf$Vowelratio))
    disc_phymed_int = c(disc_phymed_int, median(Vowelratiodf$Vowelratio))
    disc_phymeans_int_sd= c(disc_phymeans_int_sd, sd(Vowelratiodf$Vowelratio))
  }
  
}
newdf$disc_phymed_int = disc_phymed_int
newdf$disc_phymeans_int = disc_phymeans_int
newdf$disc_phymeans_int_sd = disc_phymeans_int_sd


write.csv(newdf, file = 'purelin_df_vowelratio.csv')


save(geodist,file = 'geodist_vowelratio.rda')
save(phydist,file = 'phylodist_vowelratio.rda')
