library(cmdstanr)
library(rstan)
library("loo")

purelindf = read.csv('purelin_df_vowelratio.csv')



purelindf$mH = as.vector(scale(purelindf$mH, center = F))

purelindf[is.na(purelindf)] = 0

data_list_real = list(
  'T_obs' = purelindf$Vowelratio[purelindf$Vowelratio.sd == 0],
  'T_rec' = purelindf$Vowelratio[purelindf$Vowelratio.sd != 0],
  'Nobs' = length(purelindf$Vowelratio[purelindf$Vowelratio.sd == 0]),
  'Nrec' = length(purelindf$Vowelratio[purelindf$Vowelratio.sd != 0]),
  'mH' = as.vector(purelindf$mH),
  'dA' = purelindf$deltaAge/1000,
  'anc' =purelindf$ancnode,
  'Nanc' = length(unique(purelindf$ancnode)),
  'N' = nrow(purelindf),
  'Tsd' = purelindf$Vowelratio.sd[purelindf$Vowelratio.sd != 0],
  'neighbourT' = purelindf$disc_neighbourmeans_int,
  'phyT' = purelindf$disc_phymeans_int,
  'neighbourT_sd' = purelindf$disc_neighbourmeans_int_sd +0.01,
  'phyT_sd' = purelindf$disc_phymeans_int_sd+0.01

)

stan_program <- "
data {
  int N;
  int<lower=1> Nobs;
  int<lower=1> Nrec;
  int<lower=1> Nanc;
  vector[Nobs] T_obs;
  vector[Nrec] T_rec;
  vector[N] mH;
  vector[N] dA;
  int anc[N];
  vector[Nrec] Tsd;
  vector[N] neighbourT;
  vector[N] phyT;
  vector[N] neighbourT_sd;
  vector[N] phyT_sd;
}

parameters {

real b;
  real bgeo;
  real bphy;
  
  real<lower=0> sigma;

  real sigma_b;
  real a;
  vector<lower=0, upper=1>[Nrec] T_imput;
  vector<lower=0>[N] neighbourT_inf;
  vector[N] phyT_inf;
  

}
transformed parameters {
vector[N] mu;
vector[N] T_merge;
  T_merge = append_row(T_obs, T_imput);
vector[N] sigma_calc;
  sigma_calc = sigma + sigma_b*dA;
  
  for(i in 1:N){
    if(anc[i] != 0){
      mu[i] = (a + b*mH[i] + bgeo*neighbourT_inf[i] + bphy*phyT_inf[i])*dA[i];
    }
  }
}

model {
  
  
  T_imput ~ normal(T_rec, Tsd);
  neighbourT_inf ~ normal(neighbourT, neighbourT_sd);
  phyT_inf ~ normal(phyT, phyT_sd);
  
  
  for(i in 1:N){
    if(anc[i] != 0){
      
      T_merge[i]-T_merge[anc[i]] ~ normal(mu[i], sigma_calc[i]);
     
    }
  }

  sigma ~ exponential(5);
  sigma_b ~ normal(0,0.5);
  b ~ normal(0,0.5);
  a ~ normal(0,0.5);
  bgeo ~ normal(0,0.5);
  bphy ~ normal(0,0.5);
}
generated quantities {
  vector[N-1] log_lik;
  int counter;
  counter = 1;
  for (i in 1:N) {
    if(anc[i] != 0){
    log_lik[counter] = normal_lpdf(T_merge[i]-T_merge[anc[i]] | mu[i], sigma_calc[i]);
    counter = counter+1;
    }
  }
}
"


fileConn<-file("purelin_model_onlygeo_vowelratio.stan")
writeLines(stan_program, fileConn)
close(fileConn)
library(cmdstanr)
file <- file.path("purelin_model_onlygeo_vowelratio.stan")
mod <- cmdstan_model(file, pedantic = F)



fit <- mod$sample(
  data = data_list_real, 
  chains = 4, 
  iter_warmup  = 1000,
  iter_sampling  = 1000,
  init = 0,
  #adapt_delta = 0.99,
  show_messages = F,
  parallel_chains = 4,
  refresh = 200 # print update every 100 iters
)
fit$save_output_files(basename = "purelin_full_vowelratio")
stanfit <- rstan::read_stan_csv(fit$output_files())
log_lik_1 <- extract_log_lik(stanfit, merge_chains = FALSE)
r_eff <- relative_eff(exp(log_lik_1), cores = 2) 
loo_1 <- loo(log_lik_1, r_eff = r_eff, cores = 2)
save(loo_1, file = 'loo_purelin_full_vowelratio.rda')

stan_program <- "
data {
  int N;
  int<lower=1> Nobs;
  int<lower=1> Nrec;
  int<lower=1> Nanc;
  vector[Nobs] T_obs;
  vector[Nrec] T_rec;
  vector[N] mH;
  vector[N] dA;
  int anc[N];
  vector[Nrec] Tsd;
  vector[N] neighbourT;
  vector[N] phyT;
  vector[N] neighbourT_sd;
  vector[N] phyT_sd;
}

parameters {

real b;
  real bgeo;
  
  real<lower=0> sigma;

  real sigma_b;
  real a;
  vector<lower=0, upper=1>[Nrec] T_imput;
  vector<lower=0>[N] neighbourT_inf;
  

}
transformed parameters {
vector[N] mu;
vector[N] T_merge;
  T_merge = append_row(T_obs, T_imput);
vector[N] sigma_calc;
  sigma_calc = sigma + sigma_b*dA;
  
  for(i in 1:N){
    if(anc[i] != 0){
      mu[i] = (a + b*mH[i] + bgeo*neighbourT_inf[i])*dA[i];
      
    }
  }
}

model {
  
  
  T_imput ~ normal(T_rec, Tsd);
  neighbourT_inf ~ normal(neighbourT, neighbourT_sd);
  
  
  for(i in 1:N){
    if(anc[i] != 0){
      
      T_merge[i]-T_merge[anc[i]] ~ normal(mu[i], sigma_calc[i]);
     
    }
  }

  sigma ~ exponential(5);
  sigma_b ~ normal(0,0.5);
  b ~ normal(0,0.5);
  a ~ normal(0,0.5);
  bgeo ~ normal(0,0.5);
}
generated quantities {
  vector[N-1] log_lik;
  int counter;
  counter = 1;
  for (i in 1:N) {
    if(anc[i] != 0){
    log_lik[counter] = normal_lpdf(T_merge[i]-T_merge[anc[i]] | mu[i], sigma_calc[i]);
    counter = counter+1;
    }
  }
}
"


fileConn<-file("purelin_model_onlygeo_vowelratio.stan")
writeLines(stan_program, fileConn)
close(fileConn)
library(cmdstanr)
file <- file.path("purelin_model_onlygeo_vowelratio.stan")
mod <- cmdstan_model(file, pedantic = F)



fit <- mod$sample(
  data = data_list_real, 
  chains = 4, 
  iter_warmup  = 1000,
  iter_sampling  = 1000,
  init = 0,
  #adapt_delta = 0.99,
  show_messages = F,
  parallel_chains = 4,
  refresh = 200 # print update every 100 iters
)
fit$save_output_files(basename = "purelin_humgeo_vowelratio")
stanfit <- rstan::read_stan_csv(fit$output_files())
log_lik_1 <- extract_log_lik(stanfit, merge_chains = FALSE)
r_eff <- relative_eff(exp(log_lik_1), cores = 2) 
loo_2 <- loo(log_lik_1, r_eff = r_eff, cores = 2)
save(loo_2, file = 'loo_purelin_humgeo_vowelratio.rda')

stan_program <- "
data {
  int N;
  int<lower=1> Nobs;
  int<lower=1> Nrec;
  int<lower=1> Nanc;
  vector[Nobs] T_obs;
  vector[Nrec] T_rec;
  vector[N] mH;
  vector[N] dA;
  int anc[N];
  vector[Nrec] Tsd;
  vector[N] neighbourT;
  vector[N] phyT;
  vector[N] neighbourT_sd;
  vector[N] phyT_sd;
}

parameters {

real b;
  
  real<lower=0> sigma;

  real sigma_b;
  real a;
  vector<lower=0, upper=1>[Nrec] T_imput;
  

}
transformed parameters {
vector[N] mu;
vector[N] T_merge;
  T_merge = append_row(T_obs, T_imput);
vector[N] sigma_calc;
  sigma_calc = sigma + sigma_b*dA;
  
  for(i in 1:N){
    if(anc[i] != 0){
      mu[i] = (a + b*mH[i])*dA[i];
      
    }
  }
}

model {
  
  
  T_imput ~ normal(T_rec, Tsd);
  
  
  for(i in 1:N){
    if(anc[i] != 0){
      
      T_merge[i]-T_merge[anc[i]] ~ normal(mu[i], sigma_calc[i])  T[-1,1];
     
    }
  }

  sigma ~ exponential(5);
  sigma_b ~ normal(0,0.5);
  b ~ normal(0,0.5);
  a ~ normal(0,0.5);
}
generated quantities {
  vector[N-1] log_lik;
  int counter;
  counter = 1;
  for (i in 1:N) {
    if(anc[i] != 0){
    log_lik[counter] = normal_lpdf(T_merge[i]-T_merge[anc[i]] | mu[i], sigma_calc[i]);
    counter = counter+1;
    }
  }
}
"


fileConn<-file("purelin_model_onlygeo_vowelratio.stan")
writeLines(stan_program, fileConn)
close(fileConn)
library(cmdstanr)
file <- file.path("purelin_model_onlygeo_vowelratio.stan")
mod <- cmdstan_model(file, pedantic = F)



fit <- mod$sample(
  data = data_list_real, 
  chains = 4, 
  iter_warmup  = 1000,
  iter_sampling  = 1000,
  init = 0,
  #adapt_delta = 0.99,
  show_messages = F,
  parallel_chains = 4,
  refresh = 200 # print update every 100 iters
)
fit$save_output_files(basename = "purelin_onlyhum_vowelratio")
stanfit <- rstan::read_stan_csv(fit$output_files())
log_lik_1 <- extract_log_lik(stanfit, merge_chains = FALSE)
r_eff <- relative_eff(exp(log_lik_1), cores = 2) 
loo_3 <- loo(log_lik_1, r_eff = r_eff, cores = 2)
save(loo_3, file = 'loo_purelin_onlyhum_vowelratio.rda')

comp <- loo_compare(loo_1, loo_2, loo_3)
save(comp, file = 'comp_purelin_vowelratio.rda')
print(comp)
