library(bayestraitr)
library(phylobase)
library(phylosignal)
load('GTree_phylo4g_withClimateSimData.RDat')
d = bt_read.log("Anc_Tones_continuous_est.Log.txt")



tree.chosen = tree4d
tips.to.remove  = tree4d@label[is.na(tree4d@data[1:length(tree4d@label),]$Tones)]
tree.chosen = prune(tree.chosen,tips.exclude = tips.to.remove, trim.internal=T)
edges = tree.chosen@edge
edgelengths = tree.chosen@edge.length
anc = apply(d[,grepl("^Est",names(d))],2,mean)
ancsd = apply(d[,grepl("^Est",names(d))],2,sd)


df = as.data.frame(tree.chosen@data)
df$node = 1:nrow(df)
df = df[,c('node', 'Longitude', 'Latitude', 'specH.mean', "Node.Age", 'Tones', 'specH.mean.sim.gam')]
df$Tones.sd = 0

df$Tones[211] = 2
df$Tones.sd[211] = 0
df$Tones[212:419] = anc
df$Tones.sd[212:419] = ancsd
dat = df
dat$specH.mean.sim.gam2 = dat$specH.mean.sim.gam
dat$specH.mean.sim.gam = scale(dat$specH.mean.sim.gam, center = F)

hist(dat$specH.mean.sim.gam)

big_df = data.frame()
for (run in 1:100){
  print(run/100)
  for(level in 0){
  
    res_df = data.frame('node' = 211, 'H' = dat$specH.mean.sim.gam[dat$node==211], 'T' = 2, 'dA' = NA, 'mH' = NA, 'ancT' = NA, 'level' = NA,
                        'run' = NA)
    for (i in 2:nrow(edges)) {
      anc = edges[i, 1]
      desc = edges[i, 2]
      edgelength = edgelengths[paste(c(as.character(anc), '-', as.character(desc)), collapse = '')]
      ancH = dat$specH.mean.sim.gam[dat$node==anc]
      descH = dat$specH.mean.sim.gam[dat$node==desc]
      ancT = res_df$T[res_df$node==anc]
      descT = max(ancT + rnorm(0,1)*(edgelength/1000),0)
      if(descT == Inf | is.na(descT)){
        descT = 0
      }
      res_df = rbind(res_df, data.frame(
        'node' = as.numeric(desc), 'H' = descH, 'T' = descT,
        'dA' = as.numeric(edgelength), 'mH' = mean(ancH, descH), 'ancT' = ancT, 'level' = level, 'run' = run
        ))
    }
    res_df = res_df[-1,]
    
    
    smry = summary(mod <- lm(T ~ H, res_df[res_df$node <=210,]))
    res_df$slope = smry$coefficients[2,1]
    res_df$significance = sum(smry$coefficients[2,4]<0.05)
    big_df = rbind(big_df, res_df)
  }
}

save(big_df, file = 'stabilityruns.rda')

load(file = 'stabilityruns.rda')


lineagedf = read.csv('lineage_df.csv')
lineagedf$specH.mean.sim.gam = NA
for (n in 1:nrow(lineagedf)) {
  lineagedf$specH.mean.sim.gam[n] = dat$specH.mean.sim.gam2[which(dat$node == lineagedf$node[n])]
}

cairo_pdf(filename = 'humtreeplot.pdf', width = 8, height = 6)
for (i in 1:length(unique(lineagedf$lineage))){
  lin = unique(lineagedf$lineage)[i]
  tmpdf = lineagedf[lineagedf$lineage == lin,]
  if(i == 1){
    plot(specH.mean.sim.gam ~ Node.Age,data =tmpdf[order(tmpdf$Node.Age),], lwd = 2, col = rgb(0,0,1,1/4), type ='l', 
         ylab = 'Humidity', xlab = 'Node age',
         ylim = c(min(lineagedf$specH.mean.sim.gam),max(lineagedf$specH.mean.sim.gam)))
  }else{
    lines(specH.mean.sim.gam ~ Node.Age,data =tmpdf[order(tmpdf$Node.Age),], lwd = 2, col = rgb(0,0,1,1/4), type ='l')
  }
}
dev.off()


cairo_pdf(filename = 'tonestreeplot.pdf', width = 8, height = 6)
for (i in 1:length(unique(lineagedf$lineage))){
  lin = unique(lineagedf$lineage)[i]
  tmpdf = lineagedf[lineagedf$lineage == lin,]
  if(i == 1){
    plot(Tones ~ Node.Age,data =tmpdf[order(tmpdf$Node.Age),], lwd = 2, col = rgb(0,0,1,1/4), type ='l', 
         ylab = 'Tones', xlab = 'Node age',
         ylim = c(min(lineagedf$Tones),max(lineagedf$Tones)))
  }else{
    lines(Tones ~ Node.Age,data =tmpdf[order(tmpdf$Node.Age),], lwd = 2, col = rgb(0,0,1,1/4), type ='l')
  }
}
dev.off()

cairo_pdf(filename = 'bothtreeplot.pdf', width = 12, height = 8)
par(mfrow = c(1,2))
for (i in 1:length(unique(lineagedf$lineage))){
  lin = unique(lineagedf$lineage)[i]
  tmpdf = lineagedf[lineagedf$lineage == lin,]
  if(i == 1){
    plot(specH.mean.sim.gam ~ Node.Age,data =tmpdf[order(tmpdf$Node.Age),], lwd = 2, col = rgb(0,0,1,1/4), type ='l', 
         ylab = 'Humidity', xlab = 'Node age',
         ylim = c(min(lineagedf$specH.mean.sim.gam),max(lineagedf$specH.mean.sim.gam)))
  }else{
    lines(specH.mean.sim.gam ~ Node.Age,data =tmpdf[order(tmpdf$Node.Age),], lwd = 2, col = rgb(0,0,1,1/4), type ='l')
  }
}

for (i in 1:length(unique(lineagedf$lineage))){
  lin = unique(lineagedf$lineage)[i]
  tmpdf = lineagedf[lineagedf$lineage == lin,]
  if(i == 1){
    plot(Tones ~ Node.Age,data =tmpdf[order(tmpdf$Node.Age),], lwd = 2, col = rgb(0,0,1,1/4), type ='l', 
         ylab = 'Tones', xlab = 'Node age',
         ylim = c(min(lineagedf$Tones),max(lineagedf$Tones)))
  }else{
    lines(Tones ~ Node.Age,data =tmpdf[order(tmpdf$Node.Age),], lwd = 2, col = rgb(0,0,1,1/4), type ='l')
  }
}
dev.off()


#examples

node1 = 320
node2 = 220
ancn = MRCA(tree.chosen, node1, node2)


cairo_pdf(filename = 'nodedispHum.pdf', width = 8, height = 6)
counter = 1
for (i in 1:length(unique(lineagedf$lineage))){
  lin = unique(lineagedf$lineage)[i]
  tmpdf = lineagedf[lineagedf$lineage == lin,]
  
  if(node1 %in% tmpdf$node){
    
    tmpdf = tmpdf[tmpdf$node >= ancn | tmpdf$node <= 210,]
    if(counter == 1){
      plot(specH.mean.sim.gam ~ Node.Age,data =tmpdf[order(tmpdf$Node.Age),], lwd = 2, col = rgb(0,0,1,1/4), type ='l', 
           ylab = 'Humidity', xlab = 'Node age',
           ylim = c(min(lineagedf$specH.mean.sim.gam),max(lineagedf$specH.mean.sim.gam)),
           xlim = c(0,max(lineagedf$Node.Age)))
      counter = counter +1
    }else{
      lines(specH.mean.sim.gam ~ Node.Age,data =tmpdf[order(tmpdf$Node.Age),], lwd = 2, col = rgb(0,0,1,1/4), type ='l')
    }
    tmpdf = lineagedf[lineagedf$lineage == lin,]
    tmpdf = tmpdf[tmpdf$node <= ancn & tmpdf$node >= 211,]
    if(counter == 1){
      plot(specH.mean.sim.gam ~ Node.Age,data =tmpdf[order(tmpdf$Node.Age),], lwd = 2, col = rgb(0,0,0,1/4), type ='l', 
           ylab = 'Humidity', xlab = 'Node age',
           ylim = c(min(lineagedf$specH.mean.sim.gam),max(lineagedf$specH.mean.sim.gam)),
           xlim = c(0,max(lineagedf$Node.Age)))
      counter = counter +1
    }else{
      lines(specH.mean.sim.gam ~ Node.Age,data =tmpdf[order(tmpdf$Node.Age),], lwd = 2, col = rgb(0,0,0,1/4), type ='l')
    }
  }
  
  if(node2 %in% tmpdf$node){
    tmpdf = tmpdf[tmpdf$node >= ancn | tmpdf$node <= 210,]
    if(counter == 1){
      plot(specH.mean.sim.gam ~ Node.Age,data =tmpdf[order(tmpdf$Node.Age),], lwd = 2, col = rgb(1,0,0,1/4), type ='l', 
           ylab = 'Humidity', xlab = 'Node age',
           ylim = c(min(lineagedf$specH.mean.sim.gam),max(lineagedf$specH.mean.sim.gam)),
           xlim = c(0,max(lineagedf$Node.Age)))
      counter = counter +1
    }else{
      lines(specH.mean.sim.gam ~ Node.Age,data =tmpdf[order(tmpdf$Node.Age),], lwd = 2, col = rgb(1,0,0,1/4), type ='l')
    }
    
    tmpdf = lineagedf[lineagedf$lineage == lin,]
    tmpdf = tmpdf[tmpdf$node <= ancn & tmpdf$node >= 211,]
    if(counter == 1){
      plot(specH.mean.sim.gam ~ Node.Age,data =tmpdf[order(tmpdf$Node.Age),], lwd = 2, col = rgb(0,0,0,1/4), type ='l', 
           ylab = 'Humidity', xlab = 'Node age',
           ylim = c(min(lineagedf$specH.mean.sim.gam),max(lineagedf$specH.mean.sim.gam)),
           xlim = c(0,max(lineagedf$Node.Age)))
      counter = counter +1
    }else{
      lines(specH.mean.sim.gam ~ Node.Age,data =tmpdf[order(tmpdf$Node.Age),], lwd = 2, col = rgb(0,0,0,1/4), type ='l')
    }
  }

  
  
}

descs = phytools::getDescendants(as(tree.chosen, 'phylo'), node1)[phytools::getDescendants(as(tree.chosen, 'phylo'), node1) <= ancn]

interv = HDInterval::hdi(dat$specH.mean.sim.gam2[descs], credMass = 0.8)

lines(c(-100,-100),c(interv[[1]], interv[[2]]), lwd = 7, col =rgb(0,0,1,0.5))
points(-100, mean(dat$specH.mean.sim.gam2[descs]), lwd = 4)

descs = phytools::getDescendants(as(tree.chosen, 'phylo'), node2)[phytools::getDescendants(as(tree.chosen, 'phylo'), node2) <= ancn]
interv = HDInterval::hdi(dat$specH.mean.sim.gam2[descs], credMass = 0.8)

lines(c(-100,-100),c(interv[[1]], interv[[2]]), lwd = 7, col =rgb(1,0,0,0.5))
points(-100, mean(dat$specH.mean.sim.gam2[descs]), lwd = 4)
dev.off()


node1 = 244
node2 = 277
ancn = MRCA(tree.chosen, node1, node2)
  
cairo_pdf(filename = 'nodedispTones.pdf', width = 8, height = 6)
counter = 1
for (i in 1:length(unique(lineagedf$lineage))){
  lin = unique(lineagedf$lineage)[i]
  tmpdf = lineagedf[lineagedf$lineage == lin,]
  
  if(node1  %in% tmpdf$node){
    
    tmpdf = tmpdf[tmpdf$node >= ancn  | tmpdf$node <= 210,]
    if(counter == 1){
      plot(Tones ~ Node.Age,data =tmpdf[order(tmpdf$Node.Age),], lwd = 2, col = rgb(0,0,1,1/4), type ='l', 
           ylab = 'Tones', xlab = 'Node age',
           ylim = c(min(lineagedf$Tones),max(lineagedf$Tones)),
           xlim = c(0,max(lineagedf$Node.Age)))
      counter = counter +1
    }else{
      lines(Tones ~ Node.Age,data =tmpdf[order(tmpdf$Node.Age),], lwd = 2, col = rgb(0,0,1,1/4), type ='l')
    }
    tmpdf = lineagedf[lineagedf$lineage == lin,]
    tmpdf = tmpdf[tmpdf$node <= ancn  & tmpdf$node >= 210,]
    if(counter == 1){
      plot(Tones ~ Node.Age,data =tmpdf[order(tmpdf$Node.Age),], lwd = 2, col = rgb(0,0,0,1/4), type ='l', 
           ylab = 'Tones', xlab = 'Node age',
           ylim = c(min(lineagedf$Tones),max(lineagedf$Tones)),
           xlim = c(0,max(lineagedf$Node.Age)))
      counter = counter +1
    }else{
      lines(Tones ~ Node.Age,data =tmpdf[order(tmpdf$Node.Age),], lwd = 2, col = rgb(0,0,0,1/4), type ='l')
    }
  }
  
  if(node2 %in% tmpdf$node){
    tmpdf = tmpdf[tmpdf$node >= ancn  | tmpdf$node <= 210,]
    if(counter == 1){
      plot(Tones ~ Node.Age,data =tmpdf[order(tmpdf$Node.Age),], lwd = 2, col = rgb(1,0,0,1/4), type ='l', 
           ylab = 'Tones', xlab = 'Node age',
           ylim = c(min(lineagedf$Tones),max(lineagedf$Tones)),
           xlim = c(0,max(lineagedf$Node.Age)))
      counter = counter +1
    }else{
      lines(Tones ~ Node.Age,data =tmpdf[order(tmpdf$Node.Age),], lwd = 2, col = rgb(1,0,0,1/4), type ='l')
    }
    
    tmpdf = lineagedf[lineagedf$lineage == lin,]
    tmpdf = tmpdf[tmpdf$node <= ancn  & tmpdf$node >= 210,]
    if(counter == 1){
      plot(Tones ~ Node.Age,data =tmpdf[order(tmpdf$Node.Age),], lwd = 2, col = rgb(0,0,0,1/4), type ='l', 
           ylab = 'Tones', xlab = 'Node age',
           ylim = c(min(lineagedf$Tones),max(lineagedf$Tones)),
           xlim = c(0,max(lineagedf$Node.Age)))
      counter = counter +1
    }else{
      lines(Tones ~ Node.Age,data =tmpdf[order(tmpdf$Node.Age),], lwd = 2, col = rgb(0,0,0,1/4), type ='l')
    }
  }
  
  
  
}

descs = phytools::getDescendants(as(tree.chosen, 'phylo'), node1)[phytools::getDescendants(as(tree.chosen, 'phylo'), node1) <= ancn]

interv = HDInterval::hdi(dat$Tones[descs], credMass = 0.8)

lines(c(-100,-100),c(interv[[1]], interv[[2]]), lwd = 7, col =rgb(0,0,1,0.5))
points(-100, mean(dat$Tones[descs]), lwd = 4)

descs = phytools::getDescendants(as(tree.chosen, 'phylo'), node2)[phytools::getDescendants(as(tree.chosen, 'phylo'), node2) <= ancn]
interv = HDInterval::hdi(dat$Tones[descs], credMass = 0.8)

lines(c(-100,-100),c(interv[[1]], interv[[2]]), lwd = 7, col =rgb(1,0,0,0.5))
points(-100, mean(dat$Tones[descs]), lwd = 4)
dev.off()



cairo_pdf(filename = 'bothdispplot.pdf', width = 12, height = 6)
par(mfrow = c(1,2))
counter = 1
for (i in 1:length(unique(lineagedf$lineage))){
  lin = unique(lineagedf$lineage)[i]
  tmpdf = lineagedf[lineagedf$lineage == lin,]
  
  if(394 %in% tmpdf$node){
    
    tmpdf = tmpdf[tmpdf$node >= 317 | tmpdf$node <= 210,]
    if(counter == 1){
      plot(specH.mean.sim.gam ~ Node.Age,data =tmpdf[order(tmpdf$Node.Age),], lwd = 2, col = rgb(0,0,1,1/4), type ='l', 
           ylab = 'Humidity', xlab = 'Node age',
           ylim = c(min(lineagedf$specH.mean.sim.gam),max(lineagedf$specH.mean.sim.gam)),
           xlim = c(0,max(lineagedf$Node.Age)))
      counter = counter +1
    }else{
      lines(specH.mean.sim.gam ~ Node.Age,data =tmpdf[order(tmpdf$Node.Age),], lwd = 2, col = rgb(0,0,1,1/4), type ='l')
    }
    tmpdf = lineagedf[lineagedf$lineage == lin,]
    tmpdf = tmpdf[tmpdf$node <= 317 & tmpdf$node >= 211,]
    if(counter == 1){
      plot(specH.mean.sim.gam ~ Node.Age,data =tmpdf[order(tmpdf$Node.Age),], lwd = 2, col = rgb(0,0,0,1/4), type ='l', 
           ylab = 'Humidity', xlab = 'Node age',
           ylim = c(min(lineagedf$specH.mean.sim.gam),max(lineagedf$specH.mean.sim.gam)),
           xlim = c(0,max(lineagedf$Node.Age)))
      counter = counter +1
    }else{
      lines(specH.mean.sim.gam ~ Node.Age,data =tmpdf[order(tmpdf$Node.Age),], lwd = 2, col = rgb(0,0,0,1/4), type ='l')
    }
  }
  
  if(322 %in% tmpdf$node){
    tmpdf = tmpdf[tmpdf$node >= 317 | tmpdf$node <= 210,]
    if(counter == 1){
      plot(specH.mean.sim.gam ~ Node.Age,data =tmpdf[order(tmpdf$Node.Age),], lwd = 2, col = rgb(1,0,0,1/4), type ='l', 
           ylab = 'Humidity', xlab = 'Node age',
           ylim = c(min(lineagedf$specH.mean.sim.gam),max(lineagedf$specH.mean.sim.gam)),
           xlim = c(0,max(lineagedf$Node.Age)))
      counter = counter +1
    }else{
      lines(specH.mean.sim.gam ~ Node.Age,data =tmpdf[order(tmpdf$Node.Age),], lwd = 2, col = rgb(1,0,0,1/4), type ='l')
    }
    
    tmpdf = lineagedf[lineagedf$lineage == lin,]
    tmpdf = tmpdf[tmpdf$node <= 317 & tmpdf$node >= 211,]
    if(counter == 1){
      plot(specH.mean.sim.gam ~ Node.Age,data =tmpdf[order(tmpdf$Node.Age),], lwd = 2, col = rgb(0,0,0,1/4), type ='l', 
           ylab = 'Humidity', xlab = 'Node age',
           ylim = c(min(lineagedf$specH.mean.sim.gam),max(lineagedf$specH.mean.sim.gam)),
           xlim = c(0,max(lineagedf$Node.Age)))
      counter = counter +1
    }else{
      lines(specH.mean.sim.gam ~ Node.Age,data =tmpdf[order(tmpdf$Node.Age),], lwd = 2, col = rgb(0,0,0,1/4), type ='l')
    }
  }
  
  
  
}

points(dat$Node.Age[dat$node == 322],dat$specH.mean.sim.gam2[dat$node == 322] , lwd = 2, col =rgb(0,0,0,0.9), pch  =16, cex = 1.5)
points(dat$Node.Age[dat$node == 394],dat$specH.mean.sim.gam2[dat$node == 394] , lwd = 2, col =rgb(0,0,0,0.9), pch  =16, cex = 1.5)

descs = phytools::getDescendants(as(tree.chosen, 'phylo'), 322)[phytools::getDescendants(as(tree.chosen, 'phylo'), 322) <= 211]

interv = HDInterval::hdi(dat$specH.mean.sim.gam2[descs], credMass = 0.8)

lines(c(-100,-100),c(interv[[1]], interv[[2]]), lwd = 7, col =rgb(1,0,0,0.5))

descs = phytools::getDescendants(as(tree.chosen, 'phylo'), 394)[phytools::getDescendants(as(tree.chosen, 'phylo'), 394) <= 394]
interv = HDInterval::hdi(dat$specH.mean.sim.gam2[descs], credMass = 0.8)

lines(c(-100,-100),c(interv[[1]], interv[[2]]), lwd = 7, col =rgb(0,0,1,0.5))

counter = 1
for (i in 1:length(unique(lineagedf$lineage))){
  lin = unique(lineagedf$lineage)[i]
  tmpdf = lineagedf[lineagedf$lineage == lin,]
  
  if(453 %in% tmpdf$node){
    
    tmpdf = tmpdf[tmpdf$node >= 317 | tmpdf$node <= 210,]
    if(counter == 1){
      plot(Tones ~ Node.Age,data =tmpdf[order(tmpdf$Node.Age),], lwd = 2, col = rgb(0,0,1,1/4), type ='l', 
           ylab = 'Tones', xlab = 'Node age',
           ylim = c(min(lineagedf$Tones),max(lineagedf$Tones)),
           xlim = c(0,max(lineagedf$Node.Age)))
      counter = counter +1
    }else{
      lines(Tones ~ Node.Age,data =tmpdf[order(tmpdf$Node.Age),], lwd = 2, col = rgb(0,0,1,1/4), type ='l')
    }
    tmpdf = lineagedf[lineagedf$lineage == lin,]
    tmpdf = tmpdf[tmpdf$node <= 317 & tmpdf$node >= 211,]
    if(counter == 1){
      plot(Tones ~ Node.Age,data =tmpdf[order(tmpdf$Node.Age),], lwd = 2, col = rgb(0,0,0,1/4), type ='l', 
           ylab = 'Tones', xlab = 'Node age',
           ylim = c(min(lineagedf$Tones),max(lineagedf$Tones)),
           xlim = c(0,max(lineagedf$Node.Age)))
      counter = counter +1
    }else{
      lines(Tones ~ Node.Age,data =tmpdf[order(tmpdf$Node.Age),], lwd = 2, col = rgb(0,0,0,1/4), type ='l')
    }
  }
  
  if(327 %in% tmpdf$node){
    tmpdf = tmpdf[tmpdf$node >= 317 | tmpdf$node <= 210,]
    if(counter == 1){
      plot(Tones ~ Node.Age,data =tmpdf[order(tmpdf$Node.Age),], lwd = 2, col = rgb(1,0,0,1/4), type ='l', 
           ylab = 'Tones', xlab = 'Node age',
           ylim = c(min(lineagedf$Tones),max(lineagedf$Tones)),
           xlim = c(0,max(lineagedf$Node.Age)))
      counter = counter +1
    }else{
      lines(Tones ~ Node.Age,data =tmpdf[order(tmpdf$Node.Age),], lwd = 2, col = rgb(1,0,0,1/4), type ='l')
    }
    
    tmpdf = lineagedf[lineagedf$lineage == lin,]
    tmpdf = tmpdf[tmpdf$node <= 317 & tmpdf$node >= 211,]
    if(counter == 1){
      plot(Tones ~ Node.Age,data =tmpdf[order(tmpdf$Node.Age),], lwd = 2, col = rgb(0,0,0,1/4), type ='l', 
           ylab = 'Tones', xlab = 'Node age',
           ylim = c(min(lineagedf$Tones),max(lineagedf$Tones)),
           xlim = c(0,max(lineagedf$Node.Age)))
      counter = counter +1
    }else{
      lines(Tones ~ Node.Age,data =tmpdf[order(tmpdf$Node.Age),], lwd = 2, col = rgb(0,0,0,1/4), type ='l')
    }
  }
  
  
  
}
points(dat$Node.Age[dat$node == 327],dat$Tones[dat$node == 327] , lwd = 2, col =rgb(0,0,0,0.9), pch  =16, cex = 1.5)
points(dat$Node.Age[dat$node == 453],dat$Tones[dat$node == 453] , lwd = 2, col =rgb(0,0,0,0.9), pch  =16, cex = 1.5)

descs = phytools::getDescendants(as(tree.chosen, 'phylo'), 327)[phytools::getDescendants(as(tree.chosen, 'phylo'), 327) <= 211]

interv = HDInterval::hdi(dat$Tones[descs], credMass = 0.8)

lines(c(-100,-100),c(interv[[1]], interv[[2]]), lwd = 7, col =rgb(1,0,0,0.5))

descs = phytools::getDescendants(as(tree.chosen, 'phylo'), 453)[phytools::getDescendants(as(tree.chosen, 'phylo'), 453) <= 394]
interv = HDInterval::hdi(dat$Tones[descs], credMass = 0.8)

lines(c(-100,-100),c(interv[[1]], interv[[2]]), lwd = 7, col =rgb(0,0,1,0.5))
dev.off()




newdf = aggregate(. ~ run, big_df, FUN = mean)

cairo_pdf(filename = 'slopehist.pdf', width = 8, height = 6)

hist(newdf$slope, xlim = c(-21,21), lwd = 0.1, col = rgb(0,0,1,1/4), breaks = 15, main = 'Distribution of linear model slopes \n on simulated datasets', xlab = "Slope magnitude", ylab = '',
     border=F, probability = T)
dev.off()


table(newdf$significance)#73

cordf = data.frame('node' = unique(big_df$node), 'cor' = NA)

cordf$age = NA
cordf$ndesc = NA

for(n in 1:nrow(cordf)){
  cordf$cor[n] = cor(big_df$T[big_df$node == cordf$node[n]], big_df$slope[big_df$node == cordf$node[n]])
  cordf$age[n] = dat$Node.Age[dat$node == cordf$node[n]]
  descs = phytools::getDescendants(as(tree.chosen, 'phylo'), cordf$node[n])[phytools::getDescendants(as(tree.chosen, 'phylo'), cordf$node[n]) <= 211]
  cordf$ndesc[n] = length(descs)
}

#######sensitivity


sensitivity_df = data.frame()
baseslope = summary(m <- lm(Tones ~ specH.mean.sim.gam,lineagedf[!duplicated(lineagedf$node) & lineagedf$node <= 210,]))
baseslope = baseslope$coefficients[2,1]


for (i in 1:length(unique(lineagedf$node))){
  print(i/length(unique(lineagedf$node)))
  node = unique(lineagedf$node)[i]
  
  lins = lineagedf$lineage[which(lineagedf$node == node)]
  supra_df = data.frame()
  for (lin in 1:length(lins)){
    lineag = lins[lin]
    tmpdf = lineagedf[lineagedf$lineage == lineag,]
    tmpdf = tmpdf[order(tmpdf$Node.Age),]
    tmpdf$Tones[1:which(tmpdf$node == node)] = tmpdf$Tones[1:which(tmpdf$node == node)]+1
    supra_df = rbind(supra_df, tmpdf)
  }
  newlindf = lineagedf
  for(r in 1:nrow(newlindf)){
    if(newlindf$node[r] %in% supra_df$node){
      newlindf$Tones[r] = supra_df$Tones[which(supra_df$node ==newlindf$node[r])[1]]
    }
  }
  newlindf = newlindf[!duplicated(newlindf$node),]
  newcor = cor(newlindf$Tones, newlindf$specH.mean.sim.gam)
  newslope = summary(m <- lm(Tones ~ specH.mean.sim.gam,newlindf[!duplicated(newlindf$node) & newlindf$node <= 210,]))
  newslope = newslope$coefficients[2,1]
  sensitivity_df = rbind(sensitivity_df, data.frame('node' = node, 'dCor' = newslope-baseslope))
}
save(sensitivity_df, file = 'sensitivity_df.rda')

load(file = 'sensitivity_df.rda')

sensitivity_df$dCor_abs = abs(sensitivity_df$dCor)
sensitivity_df$age = NA
sensitivity_df$ndesc = NA

for(n in 1:nrow(sensitivity_df)){
  sensitivity_df$age[n] = dat$Node.Age[dat$node == sensitivity_df$node[n]]
  descs = phytools::getDescendants(as(tree.chosen, 'phylo'), sensitivity_df$node[n])[phytools::getDescendants(as(tree.chosen, 'phylo'), sensitivity_df$node[n]) <= 211]
  sensitivity_df$ndesc[n] = length(descs)
}


plot(dCor_abs ~ age,sensitivity_df)
plot(dCor_abs ~ ndesc,sensitivity_df)

rbPal <- colorRampPalette(c('red','blue'))
sensitivity_df$Col <- rbPal(20)[as.numeric(cut(sensitivity_df$dCor_abs,breaks = 20))]

cairo_pdf(filename = 'sensitivityscatter.pdf', width = 8, height = 6)
plot(ndesc ~ age, col = Col, sensitivity_df, lwd = 2)
dev.off()


library(ggtree)
library(treeio)
library(bayestestR)
library(ggplot2)


ggobj <- ggtree(tree.chosen) + geom_nodepoint(aes(col = sensitivity_df$dCor_abs[order(sensitivity_df$node)]), size = 3, show.legend = FALSE)+   
  scale_color_gradient(low = "blue", high = "red")


cairo_pdf(filename = 'sensitivitytree.pdf', width = 8, height = 12)
plot(ggobj)
dev.off()

